raytraverse.renderer
==========================================================

Renderer
---------------------------

.. autoclass:: raytraverse.renderer.Renderer
    :members:
    :undoc-members:
    :show-inheritance:

RadianceRenderer
---------------------------

.. autoclass:: raytraverse.renderer.RadianceRenderer
    :members:
    :undoc-members:
    :show-inheritance:

Rtrace
--------------------------------

.. autoclass:: raytraverse.renderer.Rtrace
    :members:
    :undoc-members:
    :show-inheritance:

Rcontrib
--------------------------------

.. autoclass:: raytraverse.renderer.Rcontrib
    :members:
    :undoc-members:
    :show-inheritance:

ImageRenderer
--------------------------------

.. autoclass:: raytraverse.renderer.ImageRenderer
    :members:
    :undoc-members:
    :show-inheritance:
